summaryrefslogtreecommitdiffstats
path: root/include/unotools
diff options
context:
space:
mode:
Diffstat (limited to 'include/unotools')
-rw-r--r--include/unotools/configmgr.hxx10
1 files changed, 5 insertions, 5 deletions
diff --git a/include/unotools/configmgr.hxx b/include/unotools/configmgr.hxx
index fe6a13545ed0..fd2dbb2455c2 100644
--- a/include/unotools/configmgr.hxx
+++ b/include/unotools/configmgr.hxx
@@ -71,11 +71,11 @@ public:
SAL_DLLPRIVATE void registerConfigItem(utl::ConfigItem * item);
- // Avoid using the config layer and rely on defaults
- // which is only useful for special test tool targets
- // where start-up speed is of the essence
- static bool IsAvoidConfig();
- static void EnableAvoidConfig();
+ // Avoid using the config layer and rely on defaults which is only useful
+ // for special test tool targets (typically fuzzing) where start-up speed
+ // is of the essence
+ static bool IsFuzzing();
+ static void EnableFuzzing();
private: